@@ -1,9 +1,12 @@
 from taskw.reading import load_tasks, load_config
 from taskw.writing import task_add, task_done
+from taskw.utils import clean_task, task2str
 
 __all__ = [
     load_tasks,
     load_config,
     task_add,
     task_done,
+    clean_task,
+    task2str,
 ]
